summaryrefslogtreecommitdiff
path: root/start-container-docker.sh
diff options
context:
space:
mode:
authorMaxim Kuvyrkov <maxim.kuvyrkov@linaro.org>2017-04-17 11:48:05 +0000
committerMaxim Kuvyrkov <maxim.kuvyrkov@linaro.org>2017-04-17 11:48:05 +0000
commit517147387f4b410a9375b93c1182d664915d7a2f (patch)
treedd9275a0f01b67ee54c07415b26b31cf5e4d6308 /start-container-docker.sh
parent81342374afdaccfe06c29bbb5ad198cf30c82c72 (diff)
start-container-docker: Correct memory limit for "test" containers
Change-Id: I8ad00aec56be126e8393e3f8b90c69f24b65d448
Diffstat (limited to 'start-container-docker.sh')
-rwxr-xr-xstart-container-docker.sh7
1 files changed, 5 insertions, 2 deletions
diff --git a/start-container-docker.sh b/start-container-docker.sh
index 2afe823c..f16969d2 100755
--- a/start-container-docker.sh
+++ b/start-container-docker.sh
@@ -133,8 +133,11 @@ case ${container_arch} in
;;
esac
-# Reserve resources according to weight
-memory=$(( $weight * 7500 )) # 7.5GB per executor
+# Reserve resources according to weight and task
+case $task in
+ build) memory=$(( $weight * 7500 )) ;; # 7.5GB per executor
+ test) memory=$(( $weight * 750 )) ;; # 0.75GB per executor
+esac
pids=$(( $weight * 5000 )) # 5000 processes per executor
cpus=$(( $weight * 1000 )) # 1000 cpu shares per executor